#!/usr/local/bin/awk -E

# "Manual" is if you want the pop-up Firefox and prompt for choice.

# Demon to pass data back and forth between Windows host and Linux guest OS under VirtualBox
# See also demon-win.awk for the version running on the Windows host.
# Purposes is to run AWB on windows, and unix scripts on Linux. 

@include "init.awk"
@include "library.awk"
#@include "getopt.awk"

BEGIN {

  wicsh = readfile( Exe["wi"] )
  if(wicsh ~ /internetarchive10[ ]{0,10}[=][ ]{0,10}[0,2-9]{1,}/) {
    print "Error: wi.csh not set to internetarchive10"
    exit
  }

  Optind = Opterr = 1
  while ((C = getopt(ARGC, ARGV, "p:")) != -1) {
    if(C == "p")
      pid = verifypid(Optarg)
  }


  setProject(pid)     # library.awk .. load Project[] paths via project.cfg
                      # if -p not given, use default noted in project.cfg

  main()

}

function main(    name,tempid,article) {

  removefile(Ramdisk "name.txt")              # Clear out old files
  removefile(Ramdisk "article.txt")
  removefile(Ramdisk "abort.txt")
  removefile(Ramdisk "done.txt")

  prnt("\ndemon-lin-manual.awk: Waiting for " Ramdisk "name.txt ...")

  while(1) {

    sleep(2)
    Z++
    if(Z > 500) exit   # time-out. 2500 = about 90 minutes w/ 2sec sleep

    if( checkexists(Ramdisk "name.txt") ) {

      Z = 0             # reset time-out

      name = strip( readfile(Ramdisk "name.txt") )
      prnt("demon-lin-manual.awk: New job request: " name )
      removefile(Ramdisk "name.txt")
      removefile(Ramdisk "done.txt")

      if(length(name) > 0) {           

        if( ! nameisinfile(name, Project["index"] ) ) {
          abort("demon-lin-manual.awk: Error name not found in " Project["index"] ". " name)
        }
        else {
          tempid = whatistempid(name, Project["index"] )
          if(tempid == "" || tempid == 0) {
            abort("demon-lin-manuai.awk: Error unknown tempid (" tempid ") for: " name)
          }        
          else {
            article = getwikisource(name, "dontfollow")
            if(length(article) == 0) {
              abort("demon-lin-manual.awk: Error unable to retrieve wikipedia wikisource. " name)
            }
            else {                                                     # Refresh article.txt
              sys2var( Exe["mv"] " " tempid "article.txt " tempid "article.txt.demon-lin-manual")
              print article > tempid "article.txt"
              close(tempid "article.txt")                              # Run wi.csh
              command = Exe["wi"] " -n \"" name "\" -p \"" Project["id"] "\""
              system(command)
              if(checkexists(Homeshared "article.txt") ) {
                homearticle = readfile(Homeshared "article.txt")
                print homearticle > Ramdisk "article.txt"
                close(Ramdisk "article.txt")
                prnt("demon-lin-manual.awk: Status successful. Copied article.txt to shared directory. " name) 
                print "done" > Ramdisk "done.txt"
                close(Ramdisk "done.txt")
              }
              else {
                abort("demon-lin-manual.awk: Warning article.txt missing. " name)
              }
            }
          }
        }
      }
      else {
        abort("demon-lin-manual.awk: error retrieving name")
      }  
      prnt("\ndemon-lin-manual.awk: Waiting for " Ramdisk "name.txt ...")
    }
  }
}

#
# Return 1 if name is in file 
#
function nameisinfile(name, filepath,      s, a, re) {

  if(! checkexists(filepath) ) {
    abort("demon-lin-manual.awk: Error unable to find " filepath ". " name )
    return 0
  }
  re = "^" regesc(strip(name)) "$"
  while ((getline s < filepath ) > 0) {
    split(s, a, "|")
    if(strip(a[1]) ~ re) {
      close(filepath)
      return 1
    }
  }
  close(filepath)
  return 0
}

#              
# Return the path/tempid of a name (eg. /home/adminuser/wi-awb/temp/wi-awb-0202173111/)       
#
function whatistempid(name, filepath,      s, a, re) {

  if(! checkexists(filepath) ) {           
    abort("demon-lin.awk: Error unable to find " filepath ". " name )
    return 0
  }
  re = "^" regesc(strip(name)) "$"
  while ((getline s < filepath ) > 0) {
    split(s, a, "|")
    if(strip(a[1]) ~ re) {     
      close(filepath)         
      return strip(a[2])
    }
  }
  close(filepath)
  return 0
}

#
# Abort 
#
function abort(msg,  filen) {
  if( length(msg) > 0 ) 
    prnt(msg)
  printf "0" > Ramdisk "abort.txt"
  close(Ramdisk "abort.txt")
}

#
# Print and log messages
#
function prnt(msg) {
  if( length(msg) > 0 ) {
    print(msg)
    print(strftime("%Y%m%d %H:%M:%S") " " msg) >> Home "demon-lin.log"
    close(Home "demon-lin.log")
  }
}

function removefile(str) {
      if( checkexists(str) )
        sys2var( Exe["rm"] " -- " str)
      if( checkexists(str) ) {
        abort("demon-lin-manual.awk: Error unable to delete " str ", aborting.")
        exit
      }
      system("") # Flush buffer
}

#
# Sleep 
#
function sleep(seconds)
{
  sys2var( Exe["sleep"] " " seconds)
}



